Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(464)

Unified Diff: ash/system/tray/system_tray_delegate.h

Issue 14139003: Chrome OS multi-profiles backend and UI. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: move IsMultiProfilesEnabled() out of cros Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/shell_delegate.h ('k') | ash/system/tray/test_system_tray_delegate.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/system/tray/system_tray_delegate.h
diff --git a/ash/system/tray/system_tray_delegate.h b/ash/system/tray/system_tray_delegate.h
index ba6a24f2a27d38e9a0d2c811710441add38bc22b..7d079eb9d6a05cb5ee651d459c636f19d3b4bb5a 100644
--- a/ash/system/tray/system_tray_delegate.h
+++ b/ash/system/tray/system_tray_delegate.h
@@ -110,6 +110,8 @@ typedef std::vector<IMEInfo> IMEInfoList;
class VolumeControlDelegate;
+typedef std::vector<std::string> UserEmailList;
+
class SystemTrayDelegate {
public:
virtual ~SystemTrayDelegate() {}
@@ -123,13 +125,19 @@ class SystemTrayDelegate {
// Returns true if system tray should be visible on startup.
virtual bool GetTrayVisibilityOnStartup() = 0;
// Gets information about the logged in user.
virtual const base::string16 GetUserDisplayName() const = 0;
virtual const std::string GetUserEmail() const = 0;
virtual const gfx::ImageSkia& GetUserImage() const = 0;
virtual user::LoginStatus GetUserLoginStatus() const = 0;
virtual bool IsOobeCompleted() const = 0;
+ // Returns a list of all logged in users.
+ virtual void GetLoggedInUsers(UserEmailList* users) = 0;
+
+ // Switches to another active user (if that user has already signed in).
+ virtual void SwitchActiveUser(const std::string& email) = 0;
+
// Shows UI for changing user's profile picture.
virtual void ChangeProfilePicture() = 0;
@@ -184,6 +192,9 @@ class SystemTrayDelegate {
// Shows information about enterprise enrolled devices.
virtual void ShowEnterpriseInfo() = 0;
+ // Shows login UI to add other users to this session.
+ virtual void ShowUserLogin() = 0;
+
// Attempts to shut down the system.
virtual void ShutDown() = 0;
« no previous file with comments | « ash/shell_delegate.h ('k') | ash/system/tray/test_system_tray_delegate.h » ('j') | no next file with comments »
@@ -123,13 +125,19 @@ class SystemTrayDelegate {
// Returns true if system tray should be visible on startup.
virtual bool GetTrayVisibilityOnStartup() = 0;
- // Gets information about the logged in user.
+ // Gets information about the active user.
virtual const base::string16 GetUserDisplayName() const = 0;
virtual const std::string GetUserEmail() const = 0;

Powered by Google App Engine
This is Rietveld 408576698